from django.forms import ClearableFileInput
from django.forms import EmailInput as DjangoEmailInput


class EmailInput(DjangoEmailInput):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def get_context(self, *args, **kwargs):
        context = super().get_context(*args, **kwargs)
        classes = context["widget"]["attrs"]["class"].split()

        if "emailinput" in classes:
            # Django includes this class; it's not the end of the world to keep it
            # but we remove it to keep things clean and avoid accidental styling

            classes.remove("emailinput")

        # The correct class to use with Bulma is "input", so we just need to add it
        classes.append("input")
        context["widget"]["attrs"]["class"] = " ".join(classes)

        return context


class FileUploadInput(ClearableFileInput):
    template_name = 'bulma/widgets/file_upload_input.html'



from django.forms import EmailField as DjangoEmailField
from django.forms import FileField as DjangoFileField
from django.forms import ImageField as DjangoImageField

from django_crispy_bulma.widgets import EmailInput, FileUploadInput


class EmailField(DjangoEmailField):
    widget = EmailInput()


class ImageField(DjangoImageField):
    widget = FileUploadInput()


class FileField(DjangoFileField):
    widget = FileUploadInput()



from crispy_forms.layout import (
    BaseInput, ButtonHolder, Div, Field,
    Fieldset, HTML, Hidden, Layout, MultiField,
    MultiWidgetField
)
from crispy_forms.utils import TEMPLATE_PACK, render_field

__all__ = [
    # Defined in this file
    "Button", "Column", "IconField", "Reset", "Row", "Submit", "UploadField",

    # Imported from CrispyForms itself
    "ButtonHolder", "Div", "Field", "Fieldset", "Hidden", "HTML", "Layout",
    "MultiField", "MultiWidgetField",
]


class UploadField(Field):
    def __init__(self, *args, **kwargs):
        if 'css_class' in kwargs:
            kwargs['css_class'] += " file-input"
        else:
            kwargs['css_class'] = "file-input"

        super().__init__(*args, **kwargs)


class Submit(BaseInput):
    """
    Used to create a Submit button descriptor for the {% crispy %} template tag.
    >>> submit = Submit("Search the Site", "search this site")

    The first argument is also slugified and turned into the id for the submit button.
    """

    field_classes = "button is-primary"
    input_type = "submit"


class Button(BaseInput):
    """
    Used to create a Submit input descriptor for the {% crispy %} template tag.
    >>> button = Button("Button 1", "Press Me!")

    The first argument is also slugified and turned into the id for the button.
    """

    field_classes = "button"
    input_type = "button"


class Reset(BaseInput):
    """
    Used to create a Reset button input descriptor for the {% crispy %} template tag.
    >>> reset = Reset("Reset This Form", "Revert Me!")

    The first argument is also slugified and turned into the id for the button.
    """

    field_classes = "button is-text"
    input_type = "reset"


class Row(Div):
    """
    Layout object. It wraps fields in a div whose default class is "columns".
    >>> Row("form_field_1", "form_field_2", "form_field_3")
    """

    css_class = "columns"


class Column(Div):
    """
    Layout object. It wraps fields in a div whose default class is "column".

    >>> Column("form_field_1", "form_field_2")
    """

    css_class = "column"


class IconField(Field):
    template = "%s/layout/input_with_icon.html"

    def __init__(self, field, icon_prepend=None, icon_append=None, *args, **kwargs):
        self.field = field
        self.icon_prepend = icon_prepend
        self.icon_append = icon_append
        super().__init__(*args, **kwargs)

    def render(self, form, form_style, context, template_pack=TEMPLATE_PACK,
               extra_context=None, **kwargs):
        extra_context = extra_context.copy() if extra_context is not None else {}
        extra_context.update({
            "icon_prepend": self.icon_prepend,
            "icon_append": self.icon_append,
        })
        template = self.get_template_name(template_pack)

        return render_field(
            self.field, form, form_style, context,
            template=template,
            template_pack=template_pack, extra_context=extra_context, **kwargs
        )



from setuptools import find_packages, setup

setup(
    name='django-crispy-bulma',
    version='0.1.2',
    description='Django application to add \'django-crispy-forms\' layout objects for Bulma.io',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    author='Python Discord',
    author_email='staff@pythondiscord.com',
    url='https://github.com/python-discord/django-crispy-bulma',
    license='MIT',
    packages=find_packages(),
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 2.0",
        "Framework :: Django :: 2.1",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    install_requires=[
        'Django>=2.0',
        'django-crispy-forms==1.7.2'
    ],
    extras_require={
        "dev": [
            "flake8",
            "flake8-bugbear",
            "flake8-import-order",
            "flake8-tidy-imports",
            "flake8-todo",
            "flake8-string-format",
            "pdoc",
            "pre-commit",
            "PyGithub",
            "wheel",
        ]
    },
    include_package_data=True,
    zip_safe=False
)
